"use strict";
var index_1 = require("../index");
var assert = require("assert");
describe("initial test", function () {
    it("should pass", function () {
        index_1.reinit();
        assert(index_1.getCss() === '');
        index_1.style({ color: 'red' });
        assert.equal(index_1.getCss(), '.f1jvcvsh{color:red}');
    });
    it("reinit should clear", function () {
        index_1.reinit();
        assert(index_1.getCss() === '');
        index_1.style({ color: 'red' });
        assert.equal(index_1.getCss(), '.f1jvcvsh{color:red}');
    });
    it("child same", function () {
        index_1.reinit();
        index_1.style({ color: 'red', $nest: { '&>*': { color: 'red' } } });
        assert.equal(index_1.getCss(), '.f1nv0def,.f1nv0def>*{color:red}');
    });
    it("child same unique", function () {
        index_1.reinit();
        index_1.style({ color: 'red', $nest: { '&>*': { color: 'red', $unique: true } } });
        assert.equal(index_1.getCss(), '.f1nv0def{color:red}.f1nv0def>*{color:red}');
    });
    it("child different", function () {
        index_1.reinit();
        index_1.style({ color: 'red', $nest: { '&>*': { color: 'blue' } } });
        assert.equal(index_1.getCss(), '.fv84gyi{color:red}.fv84gyi>*{color:blue}');
    });
    it("media same", function () {
        index_1.reinit();
        index_1.style({
            color: 'red',
            $nest: {
                '@media (min-width: 400px)': { color: 'red' }
            }
        });
        assert.equal(index_1.getCss(), '.f12z113b{color:red}@media (min-width: 400px){.f12z113b{color:red}}');
    });
    it("media different", function () {
        index_1.reinit();
        index_1.style({ color: 'red', $nest: { '@media (min-width: 400px)': { color: 'blue' } } });
        assert.equal(index_1.getCss(), '.fxfrsga{color:red}@media (min-width: 400px){.fxfrsga{color:blue}}');
    });
    it("classes should compose", function () {
        assert.equal(index_1.classes("a", "b"), "a b");
        assert.equal(index_1.classes("a", false && "b"), "a");
        assert.equal(index_1.classes("a", false && "b", "c"), "a c");
    });
    it("transparent string should render transparent in color property", function () {
        index_1.reinit();
        index_1.cssRule('.transparent', { color: 'transparent' });
        index_1.style({ color: 'transparent' });
        assert.equal(index_1.getCss(), '.transparent{color:transparent}.fwarpl0{color:transparent}');
    });
    it("should support dedupe by default", function () {
        index_1.reinit();
        index_1.style({
            color: 'blue',
            $nest: {
                '&::-webkit-input-placeholder': {
                    color: "rgba(0, 0, 0, 0)"
                },
                '&::-moz-placeholder': {
                    color: "rgba(0, 0, 0, 0)"
                },
                '&::-ms-input-placeholder': {
                    color: "rgba(0, 0, 0, 0)"
                }
            }
        });
        assert.equal(index_1.getCss(), '.f13byakl{color:blue}.f13byakl::-webkit-input-placeholder,.f13byakl::-moz-placeholder,.f13byakl::-ms-input-placeholder{color:rgba(0, 0, 0, 0)}');
    });
    it("should support $unique", function () {
        index_1.reinit();
        index_1.style({
            color: 'blue',
            $nest: {
                '&::-webkit-input-placeholder': {
                    $unique: true,
                    color: "rgba(0, 0, 0, 0)"
                },
                '&::-moz-placeholder': {
                    $unique: true,
                    color: "rgba(0, 0, 0, 0)"
                },
                '&::-ms-input-placeholder': {
                    $unique: true,
                    color: "rgba(0, 0, 0, 0)"
                }
            }
        });
        assert.equal(index_1.getCss(), '.f13byakl{color:blue}.f13byakl::-webkit-input-placeholder{color:rgba(0, 0, 0, 0)}.f13byakl::-moz-placeholder{color:rgba(0, 0, 0, 0)}.f13byakl::-ms-input-placeholder{color:rgba(0, 0, 0, 0)}');
    });
    it("should support $debugName", function () {
        index_1.reinit();
        index_1.style({
            $debugName: 'sample',
            color: 'blue',
            $nest: {
                '&:hover': {
                    color: 'rgba(0, 0, 0, 0)'
                }
            }
        });
        assert.equal(index_1.getCss(), '.sample_fy3xmhm{color:blue}.sample_fy3xmhm:hover{color:rgba(0, 0, 0, 0)}');
    });
});
